#[macro_use]
extern crate rocket;
use maud::{html, Markup};
use rocket::response::stream::{Event, EventStream};
use rocket::tokio::time::{interval, Duration};

#[get("/sse")]
async fn sse() -> EventStream![] {
    EventStream! {
        let mut interval = interval(Duration::from_secs(2));
        loop {
            interval.tick().await;
            yield Event::data(format!("Updated time: {:?}", chrono::Utc::now()));
        }
    }
}

#[get("/")]
fn index() -> Markup {
    html! {
        html {
            head {
                title { "Live Updates with SSE" }
                script {
                    "const eventSource = new EventSource('/sse');
                    eventSource.onmessage = (event) => {
                        document.getElementById('updates').innerText = event.data;
                    };"
                }
            }
            body {
                h1 { "Live Updates Example" }
                div id="updates" { "Waiting for updates..." }
            }
        }
    }
}

#[launch]
fn rocket() -> _ {
    rocket::build().mount("/", routes![index, sse])
}
